@@ -131,6 +131,12 @@ Do not dequeue jobs with a lower priority.
 
 One or more queues to dequeue jobs from, defaults to C<default>.
 
+=item tasks
+
+  tasks => ['foo', 'bar']
+
+One or more tasks to dequeue jobs for, defaults to all.
+
 =back
 
 These fields are currently available:
@@ -199,7 +205,7 @@ Job is valid for this many seconds (from now) before it expires.
   lax => 1
 
 Existing jobs this job depends on may also have transitioned to the C<failed> state to allow for it to be processed,
-defaults to C<false>. Note that this option is B<EXPERIMENTAL> and might change without warning!
+defaults to C<false>.
 
 =item notes
 
@@ -714,7 +720,7 @@ Job is valid for this many seconds (from now) before it expires.
   lax => 1
 
 Existing jobs this job depends on may also have transitioned to the C<failed> state to allow for it to be processed,
-defaults to C<false>. Note that this option is B<EXPERIMENTAL> and might change without warning!
+defaults to C<false>.
 
 =item parents
 
